==> apache-beam-2.22.0-source-release.zip: beam-release-2.22.0/website/www/site/content/en/blog/beam-summit-digital-2020.md <==
---
layout: post
title:  "Beam Digital Summit is Coming, and it's Coming Fast!"
date:   2020-05-08 00:00:01 -0800
aliases:
  - /blog/2020/05/08/beam-summit-digital-2020.html
categories: 
  - blog
authors:
  - pedro
  - mbaetens
  - mxm
---
<!--
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
-->

As some of you are already aware, the 2020 edition of the Beam Summit will be completely **digital and free**. And as you would expect from the Apache Beam community, it is coming in fast; the Beam Digital Summit will be from **June 15th to 19th**, one moth away! The conference will be spread across the course of one week with a couple of hours of program each day.

<!--more-->

<img class="center-block"
    src="/images/blog/beamsummit/beamsummit-digital.png"
    alt="Beam Summit Digital 2020">

While we would have loved to see all of you in person, we have to accept that 2020 will not be the year for that. So, we are looking at this as an opportunity to have a bigger and more inclusive event, where people who would normally not be able to travel to the summit will now be able to join, learn and share with the rest of the community.

## Providing you the best experience possible

We are going to great lengths to ensure that we provide the Beam community with the best possible experience in an online event. From audio/video quality, to an adequate schedule for our community, to making it as easy as possible to register to the event and join the sessions, to setting up ways for the community to interact and network with each other. The team behind the organization of the Beam Summit has been working on these things, and we are also teaming up with an event production company with experience in online events who are bringing in their knowledge.

So, what we want to say with this is: We will have a great event! And if you have any ideas on how to make it better, please let us know.

## Ways to participate and help

As all things Beam, this is a community effort. The door is open for participation:

1. Submit a proposal to talk. Please check out the **[Call for Papers](https://sessionize.com/beam-digital-summit-2020/)** and submit a talk. The deadline for submissions is _May 20th_!
2. Register to join as an attendee. Registration is now open at the **[registration page](https://crowdcast.io/e/beamsummit)**. Registration is free!
3. Consider sponsoring the event. If your company is interested in engaging with members of the community please check out our [sponsoring prospectus](https://drive.google.com/open?id=1EbijvZKpkWwWyMryLY9sJfyZzZk1k44v).
4. Help us get the word out. Please make sure to let your colleagues and friends in the data engineering field (and beyond!) know about the Beam Summit.

## Follow up and more information

While we will use the Crowdcast platform to broadcast the event, we will still have a full event website at [beamsummit.org](https://beamsummit.org) with details about the schedule, speakers, FAQ and everything else you need from an event. We are currently working on updating the website and will publish all event details in the next couple of weeks.

Please also follow us on [Twitter](https://twitter.com/beamsummit) or [LinkedIn](https://www.linkedin.com/company/beam-summit/) to get event updates.

==> apache-beam-2.23.0-source-release.zip: beam-release-2.23.0/website/www/site/content/en/blog/beam-summit-digital-2020.md <==
---
layout: post
title:  "Beam Summit Digital Is Coming - Register Now!"
date:   2020-05-08 00:00:01 -0800
aliases:
  - /blog/2020/05/08/beam-summit-digital-2020.html
categories: 
  - blog
authors:
  - pedro
  - mbaetens
  - mxm
---
<!--
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
-->

As some of you are already aware, the 2020 edition of the Beam Summit will be completely **digital and free**. Beam Summit Digital will take place from **August 24th to 28th**. The conference will be spread across the course of one week with a couple of hours of program each day.

<!--more-->

<img class="center-block"
    src="/images/blog/beamsummit/beamsummit-digital-2020.png"
    alt="Beam Summit Digital 2020, August 24-28">

While we would have loved to see all of you in person, we have to accept that 2020 will not be the year for that. So, we are looking at this as an opportunity to have a bigger and more inclusive event, where people who would normally not be able to travel to the summit will now be able to join, learn and share with the rest of the community.

## Providing you the best experience possible

We are going to great lengths to ensure that we provide the Beam community with the best possible experience in an online event. From audio/video quality, to an adequate schedule for our community, to making it as easy as possible to register to the event and join the sessions, to setting up ways for the community to interact and network with each other. The team behind the organization of the Beam Summit has been working on these things, and we are also teaming up with an event production company with experience in online events who are bringing in their knowledge.

So, what we want to say with this is: We will have a great event! And if you have any ideas on how to make it better, please let us know.

## Ways to participate and help

As all things Beam, this is a community effort. The door is open for participation:

1. Submit a proposal to talk. Please check out the **[Call for Papers](https://sessionize.com/beam-digital-summit-2020/)** and submit a talk. The deadline for submissions is _June 15th_!
2. Register to join as an attendee. Registration is now open at the **[registration page](https://crowdcast.io/e/beamsummit)**. Registration is free!
3. Consider sponsoring the event. If your company is interested in engaging with members of the community please check out our [sponsoring prospectus](https://drive.google.com/open?id=1EbijvZKpkWwWyMryLY9sJfyZzZk1k44v).
4. Help us get the word out. Please make sure to let your colleagues and friends in the data engineering field (and beyond!) know about the Beam Summit.

## Follow up and more information

While we will use the Crowdcast platform to broadcast the event, we will still have a full event website at [beamsummit.org](https://beamsummit.org) with details about the schedule, speakers, FAQ and everything else you need from an event. We are currently working on updating the website and will publish all event details in the next couple of weeks.

Please also follow us on [Twitter](https://twitter.com/beamsummit) or [LinkedIn](https://www.linkedin.com/company/beam-summit/) to get event updates.
